==========
polars.col
==========

Create an expression representing column(s) in a dataframe.

``col`` is technically not a function, but it can be used like one.

See the class documentation below for examples and further documentation.

-----

.. currentmodule:: polars.functions.col
.. autoclass:: ColumnFactory
   :members: __call__, __getattr__
   :noindex:
   :autosummary:
   :autosummary-nosignatures:
